@@ -114,7 +114,7 @@ get_command_line(int argc, char* argv[], struct command_line* line)
 			break;
 		case 'D':
 			error_reason("dumptofs has been deprecated, use "
-				     "--dump instead");
+				     "--dumpto instead");
 			rc = -1;
 			break;
 		case 'M':
@@ -559,7 +559,7 @@ get_dump_components(struct job_dump_data *dump,
 	/* Fill in component data */
 	num = 0;
 	rc = set_cl_element(&cl[num++], "kernel image", dump->image,
-			    &dump->image_addr, 0, 0x10000,
+			    &dump->image_addr, 0, 0x0,
 			    MAXIMUM_PHYSICAL_BLOCKSIZE);
 	if (rc)
 		goto error;
@@ -1880,6 +1880,7 @@ job_get(int argc, char* argv[], struct job_data** data)
 	job->add_files = cmdline.add_files;
 	job->data.mvdump.force = cmdline.force;
 	job->dry_run = cmdline.dry_run;
+	job->is_secure = SECURE_BOOT_AUTO;
 	/* Get job data from user input */
 	if (cmdline.help) {
 		job->command_line = 1;
