@@ -832,7 +832,7 @@ static struct zkey_command zkey_commands[] = {
 		.need_pkey_device = 1,
 		.short_desc = "Validate an existing secure AES key",
 		.long_desc = "Validate an existing secure AES key that is "
-			     "either contained in SECURE-KEY-FILE or is stored"
+			     "either contained in SECURE-KEY-FILE or is stored "
 			     "in the repository and print information about "
 			     "the key",
 		.has_options = 1,
@@ -1067,7 +1067,7 @@ static int command_generate(void)
 		return EXIT_FAILURE;
 	}
 	if (g.apqns == NULL && g.noapqncheck) {
-		warnx("Option '--noapqncheck' is only valid together with "
+		warnx("Option '--no-apqn-check' is only valid together with "
 		      "the '--apqns|-a' option");
 		util_prg_print_parse_error();
 		return EXIT_FAILURE;
@@ -1088,7 +1088,7 @@ static int command_generate(void)
 			return EXIT_FAILURE;
 		}
 		if (g.noapqncheck) {
-			warnx("Option '--noapqncheck' is not valid for "
+			warnx("Option '--no-apqn-check' is not valid for "
 			      "generating a key outside of the repository");
 			util_prg_print_parse_error();
 			return EXIT_FAILURE;
@@ -1317,7 +1317,7 @@ static int command_validate_file(void)
 		return EXIT_FAILURE;
 	}
 	if (g.noapqncheck) {
-		warnx("Option '--noapqncheck' is not valid for "
+		warnx("Option '--no-apqn-check' is not valid for "
 		      "validating a key outside of the repository");
 		util_prg_print_parse_error();
 		return EXIT_FAILURE;
@@ -1375,13 +1375,6 @@ static int command_validate_repository(void)
 {
 	int rc;
 
-	if (g.apqns == NULL && g.noapqncheck) {
-		warnx("Option '--noapqncheck' is only valid together with "
-		      "the '--apqns|-a' option");
-		util_prg_print_parse_error();
-		return EXIT_FAILURE;
-	}
-
 	rc = keystore_validate_key(g.keystore, g.name, g.apqns, g.noapqncheck,
 				   g.pkey_fd);
 
@@ -1421,7 +1414,7 @@ static int command_import(void)
 		g.sector_size = 0;
 
 	if (g.apqns == NULL && g.noapqncheck) {
-		warnx("Option '--noapqncheck' is only valid together with "
+		warnx("Option '--no-apqn-check' is only valid together with "
 		      "the '--apqns|-a' option");
 		util_prg_print_parse_error();
 		return EXIT_FAILURE;
@@ -1501,7 +1494,7 @@ static int command_change(void)
 		return EXIT_FAILURE;
 	}
 	if (g.apqns == NULL && g.noapqncheck) {
-		warnx("Option '--noapqncheck' is only valid together with "
+		warnx("Option '--no-apqn-check' is only valid together with "
 		      "the '--apqns|-a' option");
 		util_prg_print_parse_error();
 		return EXIT_FAILURE;
